package com.xinelu.manage.service.hospitalpersoncertificate;

import com.xinelu.common.core.domain.AjaxResult;
import com.xinelu.manage.dto.hospitalpersoncertificate.HospitalPersonCertificateDTO;
import com.xinelu.manage.vo.hospitalpersoncertificate.HospitalPersonCertificateVO;
import java.util.List;

/**
 * 健康咨询-科室人员资质证书信息Service接口
 *
 * @author xinyilu
 * @date 2023-02-23
 */
public interface IHospitalPersonCertificateService {
    /**
     * 查询健康咨询-科室人员资质证书信息
     *
     * @param id 健康咨询-科室人员资质证书信息主键
     * @return 健康咨询-科室人员资质证书信息
     */
    HospitalPersonCertificateVO selectHospitalPersonCertificateById(Long id);

    /**
     * 查询健康咨询-科室人员资质证书信息列表
     *
     * @param hospitalPersonCertificate 健康咨询-科室人员资质证书信息
     * @return 健康咨询-科室人员资质证书信息集合
     */
    List<HospitalPersonCertificateVO> selectHospitalPersonCertificateList(HospitalPersonCertificateDTO hospitalPersonCertificate);

    /**
     * 新增健康咨询-科室人员资质证书信息
     *
     * @param hospitalPersonCertificate 健康咨询-科室人员资质证书信息
     * @return 结果
     */
    AjaxResult insertHospitalPersonCertificate(HospitalPersonCertificateDTO hospitalPersonCertificate);

    /**
     * 修改健康咨询-科室人员资质证书信息
     *
     * @param hospitalPersonCertificate 健康咨询-科室人员资质证书信息
     * @return 结果
     */
    AjaxResult updateHospitalPersonCertificate(HospitalPersonCertificateDTO hospitalPersonCertificate);

    /**
     * 批量删除健康咨询-科室人员资质证书信息
     *
     * @param ids 需要删除的健康咨询-科室人员资质证书信息主键集合
     * @return 结果
     */
    int deleteHospitalPersonCertificateByIds(Long[] ids);
}
